@@ -658,9 +658,10 @@ class TibberHome:
         attr["off_peak_1"] = round(off_peak_1 / num1, 3) if num1 > 0 else 0
         attr["peak"] = round(peak / num0, 3) if num0 > 0 else 0
         attr["off_peak_2"] = round(off_peak_2 / num2, 3) if num2 > 0 else 0
-        if (
+        grid_company = self.info["viewer"]["home"]["meteringPointData"].get("gridCompany", "")
+        if (grid_company and
             "glitre"
-            in self.info["viewer"]["home"]["meteringPointData"]["gridCompany"].lower()
+            in grid_company.lower()
         ):
             now = now.astimezone(pytz.timezone("Europe/Oslo"))
             if now.month >= 10 or now.month <= 3:
